==> am_mod_evt_0_2.tar.gz: am_mod_evt_0_2/components/evt/language/1/barnraiser_01/edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------



// HEADERS
$lang['hdr_edit_event'] =						"edit event";
$lang['hdr_what'] =								"what?";
$lang['hdr_where'] =							"where?";
$lang['hdr_when'] =								"when?";
$lang['hdr_who'] =								"who?";
$lang['hdr_participation'] =					"participation";

// SUBMIT BUTTONS
$lang['sub_preview'] =                          "preview";
$lang['sub_edit'] =                             "add";

//BODY TEXT
$lang['txt_help'] =								"help";
$lang['txt_title'] = 							"title";
$lang['txt_synopsis'] = 						"synopsis";
$lang['txt_location'] = 						"location";
$lang['txt_location_none'] = 					"not location based";
$lang['txt_venue'] = 							"venue";
$lang['txt_start_date'] = 						"when does it start?";
$lang['txt_all_day_event'] = 					"all day event?";
$lang['txt_duration'] = 						"duration";
$lang['txt_repeat'] = 							"repeat event?";
$lang['txt_repeat_amount'] = 					"repeat times";
$lang['txt_invite'] = 							"publish";
$lang['txt_invite_msg'] = 						"send invitation message";
$lang['txt_body'] = 							"details";
$lang['txt_tag'] = 								"tag it";
$lang['txt_allocation'] = 						"allocation";
$lang['txt_status'] = 							"status";
$lang['txt_hours'] =							"hours";
$lang['txt_days'] =								"days";
$lang['txt_none'] =								"none";
$lang['txt_registered'] =						"registered people only";
$lang['txt_public'] =							"everyone (public)";
$lang['txt_picture'] =							"picture";
$lang['txt_details'] =							"details only seen by people that i've confirmed are attending";
$lang['txt_my_identity'] =						"my identity";


// ERRORS
$lang['error']['no_valid_date'] =				"Please specify the duration of the event";
$lang['error']['no_valid_time'] = 				"The date and timeformat is not valid";
$lang['error']['no_valid_end_time'] =			"The date and timeformat is not valid";
$lang['error']['not_numeric'] =					"Duration has to be a number";
$lang['error']['no_title'] = 					"The title can not be empty";
$lang['error']['no_synopsis'] = 				"Please enter synopsis for the event";
$lang['error']['no_venue'] = 					"Please specify a venue for the event";

?>

==> am_mod_evt_0_5.tar.gz: am_mod_evt_0_5/components/evt/language/1/barnraiser_01/edit.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------



// HEADERS
$lang['hdr_edit_event'] =						"edit event";
$lang['hdr_what'] =								"what?";
$lang['hdr_where'] =							"where?";
$lang['hdr_when'] =								"when?";
$lang['hdr_who'] =								"who?";
$lang['hdr_participation'] =					"participation";

// SUBMIT BUTTONS
$lang['sub_preview'] =                          "validate";
$lang['sub_edit'] =                             "add";

//BODY TEXT
$lang['txt_help'] =								"help";
$lang['txt_title'] = 							"title";
$lang['txt_synopsis'] = 						"synopsis";
$lang['txt_location'] = 						"location";
$lang['txt_location_none'] = 					"not location based";
$lang['txt_venue'] = 							"venue";
$lang['txt_start_date'] = 						"when does it start?";
$lang['txt_all_day_event'] = 					"all day event?";
$lang['txt_duration'] = 						"duration";
$lang['txt_repeat'] = 							"repeat event?";
$lang['txt_repeat_amount'] = 					"repeat times";
$lang['txt_invite'] = 							"publish";
$lang['txt_invite_msg'] = 						"send invitation message";
$lang['txt_body'] = 							"details";
$lang['txt_tag'] = 								"tag it";
$lang['txt_allocation'] = 						"allocation";
$lang['txt_status'] = 							"status";
$lang['txt_hours'] =							"hours";
$lang['txt_days'] =								"days";
$lang['txt_none'] =								"none";
$lang['txt_registered'] =						"registered people only";
$lang['txt_public'] =							"everyone (public)";
$lang['txt_picture'] =							"picture";
$lang['txt_details'] =							"details only seen by people that i've confirmed are attending";
$lang['txt_my_identity'] =						"my identity";


// ERRORS
$lang['error']['no_valid_date'] =				"Please specify the duration of the event";
$lang['error']['no_valid_time'] = 				"The date and timeformat is not valid";
$lang['error']['no_valid_end_time'] =			"The date and timeformat is not valid";
$lang['error']['not_numeric'] =					"Duration has to be a number";
$lang['error']['no_title'] = 					"The title can not be empty";
$lang['error']['no_synopsis'] = 				"Please enter synopsis for the event";
$lang['error']['no_venue'] = 					"Please specify a venue for the event";
$lang['error']['not_valid_allocation'] =		"Allocation must be a number or empty if no limit";

$lang['txt_file_to_upload'] = 						"file";
$lang['txt_file_to_upload_name'] = 					"filename";
$lang['txt_title_intro'] = 							"describe your event";
$lang['txt_title_image'] = 							"add a thumbnail image to your event";
$lang['txt_title_save'] = 							"check and save your event";
$lang['txt_title_create'] = 						"create the event";
$lang['txt_title_participation'] = 					"set participation for the event";

?>
